@@ -2,24 +2,23 @@
 #
 # This file is part of Invenio.
 # Copyright (C) 2015-2018 CERN.
+# Copyright (C) 2022 RERO.
 #
 # Invenio is free software; you can redistribute it and/or modify it
 # under the terms of the MIT License; see LICENSE file for more details.
 
 """Invenio application factory."""
 
-from __future__ import absolute_import, print_function
-
 import logging
 import os.path
 import sys
 import warnings
 
 import click
-import pkg_resources
 from flask import Flask
 from flask.cli import FlaskGroup
 from flask.helpers import get_debug_flag
+from importlib_metadata import entry_points as iter_entry_points
 
 from .signals import app_created, app_loaded
 
@@ -140,16 +139,26 @@ def create_cli(create_app=None):
 
     .. versionadded: 1.0.0
     """
-    def create_cli_app(info):
+    # Flask 2.0 removed support for passing script_info argument. Below
+    # function is thus
+    def create_cli_app(*args):
         """Application factory for CLI app.
 
         Internal function for creating the CLI. When invoked via
         ``inveniomanage`` FLASK_APP must be set.
         """
         if create_app is None:
-            # Fallback to normal Flask behavior
-            info.create_app = None
-            app = info.load_app()
+            # This part is only used for the "inveniomanage" command.
+            if len(args) == 0:
+                # Flask v2
+                # Create a barebones Flask application.
+                app = Flask("inveniomanage")
+            else:
+                # Flask v1
+                # Fallback to normal Flask behavior
+                info = args[0]
+                info.create_app = None
+                app = info.load_app()
         else:
             app = create_app(debug=get_debug_flag())
         return app
@@ -206,12 +215,12 @@ def converter_loader(app, entry_points=None, modules=None):
     """
     if entry_points:
         for entry_point in entry_points:
-            for ep in pkg_resources.iter_entry_points(entry_point):
+            for ep in set(iter_entry_points(group=entry_point)):
                 try:
                     app.url_map.converters[ep.name] = ep.load()
                 except Exception:
                     app.logger.error(
-                        'Failed to initialize entry point: {0}'.format(ep))
+                        f'Failed to initialize entry point: {ep}')
                     raise
 
     if modules:
@@ -228,19 +237,19 @@ def _loader(app, init_func, entry_points=None, modules=None):
     """
     if entry_points:
         for entry_point in entry_points:
-            for ep in pkg_resources.iter_entry_points(entry_point):
+            for ep in set(iter_entry_points(group=entry_point)):
                 try:
                     init_func(ep.load())
                 except Exception:
                     app.logger.error(
-                        'Failed to initialize entry point: {0}'.format(ep))
+                        f'Failed to initialize entry point: {ep}')
                     raise
     if modules:
         for m in modules:
             try:
                 init_func(m)
             except Exception:
-                app.logger.error('Failed to initialize module: {0}'.format(m))
+                app.logger.error(f'Failed to initialize module: {m}')
                 raise
 
 
@@ -279,7 +288,7 @@ def base_app(import_name, instance_path=None, static_folder=None,
             os.makedirs(instance_path)
     except Exception:  # pragma: no cover
         app.logger.exception(
-            'Failed to create instance folder: "{0}"'.format(instance_path)
+            f'Failed to create instance folder: "{instance_path}"'
         )
 
     return app
