@@ -2,23 +2,19 @@
 #
 # This file is part of Invenio.
 # Copyright (C) 2015-2018 CERN.
+# Copyright (C) 2022 RERO.
 #
 # Invenio is free software; you can redistribute it and/or modify it
 # under the terms of the MIT License; see LICENSE file for more details.
 
 """Test cli application."""
 
-from __future__ import absolute_import, print_function
-
 import logging
-import os
-from subprocess import call
+from unittest.mock import MagicMock, Mock, patch
 
 import pkg_resources
 import pytest
 from click.testing import CliRunner
-from flask.cli import ScriptInfo
-from mock import MagicMock, Mock, patch
 
 from invenio_base.app import create_app_factory
 from invenio_base.cli import instance
@@ -99,30 +95,25 @@ def test_migrate_secret_key():
     create_app = create_app_factory('test', config_loader=_config_loader)
     app = create_app(KWARGS_TEST=True)
 
-    script_info = ScriptInfo(create_app=lambda info: app)
-
     # Check that CLI command fails when the SECRET_KEY is not set.
-    with app.app_context():
-        runner = CliRunner()
-        result = runner.invoke(
-            instance, ['migrate-secret-key', '--old-key', 'OLD_SECRET_KEY'],
-            obj=script_info)
-        assert result.exit_code == 1
-        assert 'Error: SECRET_KEY is not set in the configuration.' in \
-            result.output
+    runner = app.test_cli_runner()
+    result = runner.invoke(
+        instance, ['migrate-secret-key', '--old-key', 'OLD_SECRET_KEY'])
+    assert result.exit_code == 1
+    assert 'Error: SECRET_KEY is not set in the configuration.' in \
+        result.output
 
     app.secret_key = "SECRET"
-    with patch('pkg_resources.EntryPoint') as MockEntryPoint:
+    with patch('importlib_metadata.entry_points') as MockEP:
         # Test that the CLI command succeeds when the entrypoint does
         # return a function.
-        entrypoint = MockEntryPoint('ep1', 'ep1')
+        entrypoint = MockEP('ep1', 'ep1', 'ep1')
         entrypoint.load.return_value = MagicMock()
-        with patch('invenio_base.cli.iter_entry_points',
-                   return_value=[entrypoint]):
+        with patch('importlib_metadata.entry_points',
+                   return_value={'invenio_base.secret_key': [entrypoint]}):
             result = runner.invoke(
                 instance, ['migrate-secret-key', '--old-key',
-                           'OLD_SECRET_KEY'],
-                obj=script_info)
+                           'OLD_SECRET_KEY'])
             assert result.exit_code == 0
             assert entrypoint.load.called
             entrypoint.load.return_value.assert_called_with(
@@ -132,14 +123,13 @@ def test_migrate_secret_key():
 
         # Test that the CLI command fails correctly when the entrypoint does
         # not return a function.
-        entrypoint = MockEntryPoint('ep2', 'ep2')
+        entrypoint = MockEP('ep2', 'ep2', 'ep2')
         entrypoint.load.return_value = 'ep2'
-        with patch('invenio_base.cli.iter_entry_points',
-                   return_value=[entrypoint]):
+        with patch('importlib_metadata.entry_points',
+                   return_value={'ep2': [entrypoint]}):
             result = runner.invoke(
                 instance, ['migrate-secret-key', '--old-key',
-                           'OLD_SECRET_KEY'],
-                obj=script_info)
+                           'OLD_SECRET_KEY'])
             assert result.exit_code == 1
             assert entrypoint.load.called
             assert 'Failed to perform migration of secret key' in result.output
